xglider package
===============

Submodules
----------

xglider.cli module
------------------

.. automodule:: xglider.cli
   :members:
   :undoc-members:
   :show-inheritance:

xglider.dev module
------------------

.. automodule:: xglider.dev
   :members:
   :undoc-members:
   :show-inheritance:

xglider.netcdf module
---------------------

.. automodule:: xglider.netcdf
   :members:
   :undoc-members:
   :show-inheritance:

xglider.plot module
-------------------

.. automodule:: xglider.plot
   :members:
   :undoc-members:
   :show-inheritance:

xglider.xglider module
----------------------

.. automodule:: xglider.xglider
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xglider
   :members:
   :undoc-members:
   :show-inheritance:
